@@ -256,9 +256,7 @@ def process_night(night: ConfigInputNight, config: Config, output: Path, night_d
     )
 
     # Internight normalization
-    internight_normalize(
-        NIGHT_INPUT_FOLDER, ref_file_path, color_ref_file_path, radii_of_extraction
-    )
+    internight_normalize(output, ref_file_path, color_ref_file_path, radii_of_extraction)
 
 
 def start_data_processing_auxiliary(config: Config):
